@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2016-08-03'; # DATE
-our $VERSION = '1.57'; # VERSION
+our $DATE = '2016-08-18'; # DATE
+our $VERSION = '1.58'; # VERSION
 
 use 5.010;
 use strict;
@@ -81,8 +81,7 @@ sub read_config {
     for my $i (0..$#{$paths}) {
         my $path           = $paths->[$i];
         my $filename = $path; $filename =~ s!.*[/\\]!!;
-        my $wanted_section = $section_config_filename_map{$filename}
-            // 'GLOBAL';
+        my $wanted_section = $section_config_filename_map{$filename};
         $log->tracef("[pericmd] Reading config file '%s' ...", $path);
         my $j = 0;
         $section_read_order{GLOBAL} = [$i, $j++];
@@ -101,7 +100,7 @@ sub read_config {
 
             my $s = $section; $s =~ s/\s*\S*=.*\z//; # strip key=value pairs
             $s = 'GLOBAL' if $s eq '';
-            next unless $s eq $wanted_section;
+            next unless !defined($wanted_section) || $s eq $wanted_section;
 
             for (keys %$hash) {
                 $res{$section}{$_} = $hash->{$_};
@@ -321,7 +320,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.57 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2016-08-03.
+This document describes version 1.58 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2016-08-18.
 
 =head1 FUNCTIONS
 
